#version 430 core

in VertexData {
	vec3 position_world;
	vec3 normal_world;
	vec2 uvTexCoord;
} vert;

layout (location = 0) out vec4 color;
layout (location = 1) out vec4 glow;

layout (binding=0) uniform sampler2D text;
layout (binding=1) uniform sampler2D glowTex;

uniform vec3 camera_world;

uniform vec3 materialCoefficients; // x = ambient, y = diffuse, z = specular 
uniform float specularAlpha;
uniform vec3 diffuseColor;

uniform float weight[5] = float[] (0.227027, 0.1945946, 0.1216216, 0.054054, 0.016216);

uniform struct DirectionalLight {
	vec3 color;
	vec3 direction;
} dirL;

uniform struct PointLight {
	vec3 color;
	vec3 position;
	vec3 attenuation;
} pointL;

vec3 phong(vec3 n, vec3 l, vec3 v, vec3 diffuseC, float diffuseF, vec3 specularC, float specularF, float alpha, bool attenuate, vec3 attenuation) {
	float d = length(l);
	l = normalize(l);
	float att = 1.0;	
	if(attenuate) att = 1.0f / (attenuation.x + d * attenuation.y + d * d * attenuation.z);
	vec3 r = reflect(-l, n);
	return (diffuseF * diffuseC * max(0, dot(n, l)) + specularF * specularC * pow(max(0, dot(r, v)), alpha)) * att; 
}

void main() {	
	/*
	vec2 tex_offset = 1.0 / textureSize(text, 0); // gets size of single texel
	vec3 n = normalize(vert.normal_world);
	vec3 v = normalize(camera_world - vert.position_world);
	
	vec3 texColor = texture(text,vert.uvTexCoord).rgb; 
	vec3 glowTexColor = texture(glowTex,vert.uvTexCoord).rgb;
	color = vec4((texColor + glowTexColor) * materialCoefficients.x, 1); // ambient
	
	// add directional light contribution
	//color.rgb += phong(n, -dirL.direction, v, dirL.color * texColor , materialCoefficients.y, dirL.color, materialCoefficients.z, specularAlpha, false, vec3(0));
			
	// add point light contribution
	//color.rgb += phong(n, pointL.position - vert.position_world, v, pointL.color * texColor , materialCoefficients.y, pointL.color, materialCoefficients.z, specularAlpha, true, pointL.attenuation);

	for(int i = 1; i < 5; ++i)
        {
            color.rgb += texture(text, vert.uvTexCoord + vec2(tex_offset.x * i, 0.0)).rgb * weight[i];
            color.rgb += texture(text, vert.uvTexCoord - vec2(tex_offset.x * i, 0.0)).rgb * weight[i];
        }
	*/
	vec3 texColor = texture(text,vert.uvTexCoord).rgb;
	color.rgb = texColor;
	glow.rgb = texColor + dirL.color + pointL.color;
	
}

